==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/9d/9d589da8075accc6addd202941595f08.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/FormBundle/EventListener/CampaignSubscriber.php */
class __TwigTemplate_25ad098c77d1c76d72ce22256cf04741 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\FormBundle\\EventListener;

use Mautic\\CampaignBundle\\CampaignEvents;
use Mautic\\CampaignBundle\\Event\\CampaignBuilderEvent;
use Mautic\\CampaignBundle\\Event\\CampaignExecutionEvent;
use Mautic\\CampaignBundle\\Executioner\\RealTimeExecutioner;
use Mautic\\CoreBundle\\Helper\\InputHelper;
use Mautic\\FormBundle\\Event\\SubmissionEvent;
use Mautic\\FormBundle\\Form\\Type\\CampaignEventFormFieldValueType;
use Mautic\\FormBundle\\Form\\Type\\CampaignEventFormSubmitType;
use Mautic\\FormBundle\\FormEvents;
use Mautic\\FormBundle\\Helper\\FormFieldHelper;
use Mautic\\FormBundle\\Model\\FormModel;
use Mautic\\FormBundle\\Model\\SubmissionModel;
use Symfony\\Component\\EventDispatcher\\EventSubscriberInterface;

class CampaignSubscriber implements EventSubscriberInterface
{
    public function __construct(
        private FormModel \$formModel,
        private SubmissionModel \$formSubmissionModel,
        private RealTimeExecutioner \$realTimeExecutioner,
        private FormFieldHelper \$formFieldHelper
    ) {
    }

    public static function getSubscribedEvents(): array
    {
        return [
            CampaignEvents::CAMPAIGN_ON_BUILD         => ['onCampaignBuild', 0],
            FormEvents::FORM_ON_SUBMIT                => ['onFormSubmit', 0],
            FormEvents::ON_CAMPAIGN_TRIGGER_DECISION  => ['onCampaignTriggerDecision', 0],
            FormEvents::ON_CAMPAIGN_TRIGGER_CONDITION => ['onCampaignTriggerCondition', 0],
        ];
    }

    /**
     * Add the option to the list.
     */
    public function onCampaignBuild(CampaignBuilderEvent \$event): void
    {
        \$trigger = [
            'label'       => 'mautic.form.campaign.event.submit',
            'description' => 'mautic.form.campaign.event.submit_descr',
            'formType'    => CampaignEventFormSubmitType::class,
            'eventName'   => FormEvents::ON_CAMPAIGN_TRIGGER_DECISION,
        ];
        \$event->addDecision('form.submit', \$trigger);

        \$trigger = [
            'label'       => 'mautic.form.campaign.event.field_value',
            'description' => 'mautic.form.campaign.event.field_value_descr',
            'formType'    => CampaignEventFormFieldValueType::class,
            'formTheme'   => '@MauticForm/FormTheme/FieldValueCondition/_campaignevent_form_field_value_widget.html.twig',
            'eventName'   => FormEvents::ON_CAMPAIGN_TRIGGER_CONDITION,
        ];
        \$event->addCondition('form.field_value', \$trigger);
    }

    /**
     * Trigger campaign event for when a form is submitted.
     */
    public function onFormSubmit(SubmissionEvent \$event): void
    {
        \$form = \$event->getSubmission()->getForm();
        \$this->realTimeExecutioner->execute('form.submit', \$form, 'form', \$form->getId());
    }

    public function onCampaignTriggerDecision(CampaignExecutionEvent \$event)
    {
        \$eventDetails = \$event->getEventDetails();

        if (null === \$eventDetails) {
            return \$event->setResult(true);
        }

        \$limitToForms = \$event->getConfig()['forms'];

        // check against selected forms
        if (!empty(\$limitToForms) && !in_array(\$eventDetails->getId(), \$limitToForms)) {
            return \$event->setResult(false);
        }

        return \$event->setResult(true);
    }

    public function onCampaignTriggerCondition(CampaignExecutionEvent \$event)
    {
        \$lead = \$event->getLead();

        if (!\$lead || !\$lead->getId()) {
            return \$event->setResult(false);
        }

        \$operators = \$this->formModel->getFilterExpressionFunctions();
        \$form      = \$this->formModel->getRepository()->findOneById(\$event->getConfig()['form']);

        if (!\$form || !\$form->getId()) {
            return \$event->setResult(false);
        }

        \$field = \$this->formModel->findFormFieldByAlias(\$form, \$event->getConfig()['field']);

        \$filter = \$this->formFieldHelper->getFieldFilter(\$field->getType());
        \$value  = InputHelper::_(\$event->getConfig()['value'], \$filter);

        \$result = \$this->formSubmissionModel->getRepository()->compareValue(
            \$lead->getId(),
            \$form->getId(),
            \$form->getAlias(),
            \$event->getConfig()['field'],
            \$value,
            \$operators[\$event->getConfig()['operator']]['expr'],
            \$field ? \$field->getType() : null
        );

        \$event->setChannel('form', \$form->getId());

        return \$event->setResult(\$result);
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/FormBundle/EventListener/CampaignSubscriber.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/FormBundle/EventListener/CampaignSubscriber.php", "/var/www/mautic-ktn/app/bundles/FormBundle/EventListener/CampaignSubscriber.php");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/9d/9d589da8075accc6addd202941595f08.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/FormBundle/EventListener/CampaignSubscriber.php */
class __TwigTemplate_25ad098c77d1c76d72ce22256cf04741 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\FormBundle\\EventListener;

use Mautic\\CampaignBundle\\CampaignEvents;
use Mautic\\CampaignBundle\\Event\\CampaignBuilderEvent;
use Mautic\\CampaignBundle\\Event\\CampaignExecutionEvent;
use Mautic\\CampaignBundle\\Executioner\\RealTimeExecutioner;
use Mautic\\CoreBundle\\Helper\\InputHelper;
use Mautic\\FormBundle\\Event\\SubmissionEvent;
use Mautic\\FormBundle\\Form\\Type\\CampaignEventFormFieldValueType;
use Mautic\\FormBundle\\Form\\Type\\CampaignEventFormSubmitType;
use Mautic\\FormBundle\\FormEvents;
use Mautic\\FormBundle\\Helper\\FormFieldHelper;
use Mautic\\FormBundle\\Model\\FormModel;
use Mautic\\FormBundle\\Model\\SubmissionModel;
use Symfony\\Component\\EventDispatcher\\EventSubscriberInterface;

class CampaignSubscriber implements EventSubscriberInterface
{
    public function __construct(
        private FormModel \$formModel,
        private SubmissionModel \$formSubmissionModel,
        private RealTimeExecutioner \$realTimeExecutioner,
        private FormFieldHelper \$formFieldHelper
    ) {
    }

    public static function getSubscribedEvents(): array
    {
        return [
            CampaignEvents::CAMPAIGN_ON_BUILD         => ['onCampaignBuild', 0],
            FormEvents::FORM_ON_SUBMIT                => ['onFormSubmit', 0],
            FormEvents::ON_CAMPAIGN_TRIGGER_DECISION  => ['onCampaignTriggerDecision', 0],
            FormEvents::ON_CAMPAIGN_TRIGGER_CONDITION => ['onCampaignTriggerCondition', 0],
        ];
    }

    /**
     * Add the option to the list.
     */
    public function onCampaignBuild(CampaignBuilderEvent \$event): void
    {
        \$trigger = [
            'label'       => 'mautic.form.campaign.event.submit',
            'description' => 'mautic.form.campaign.event.submit_descr',
            'formType'    => CampaignEventFormSubmitType::class,
            'eventName'   => FormEvents::ON_CAMPAIGN_TRIGGER_DECISION,
        ];
        \$event->addDecision('form.submit', \$trigger);

        \$trigger = [
            'label'       => 'mautic.form.campaign.event.field_value',
            'description' => 'mautic.form.campaign.event.field_value_descr',
            'formType'    => CampaignEventFormFieldValueType::class,
            'formTheme'   => '@MauticForm/FormTheme/FieldValueCondition/_campaignevent_form_field_value_widget.html.twig',
            'eventName'   => FormEvents::ON_CAMPAIGN_TRIGGER_CONDITION,
        ];
        \$event->addCondition('form.field_value', \$trigger);
    }

    /**
     * Trigger campaign event for when a form is submitted.
     */
    public function onFormSubmit(SubmissionEvent \$event): void
    {
        \$form = \$event->getSubmission()->getForm();
        \$this->realTimeExecutioner->execute('form.submit', \$form, 'form', \$form->getId());
    }

    public function onCampaignTriggerDecision(CampaignExecutionEvent \$event)
    {
        \$eventDetails = \$event->getEventDetails();

        if (null === \$eventDetails) {
            return \$event->setResult(true);
        }

        \$limitToForms = \$event->getConfig()['forms'];

        // check against selected forms
        if (!empty(\$limitToForms) && !in_array(\$eventDetails->getId(), \$limitToForms)) {
            return \$event->setResult(false);
        }

        return \$event->setResult(true);
    }

    public function onCampaignTriggerCondition(CampaignExecutionEvent \$event)
    {
        \$lead = \$event->getLead();

        if (!\$lead || !\$lead->getId()) {
            return \$event->setResult(false);
        }

        \$operators = \$this->formModel->getFilterExpressionFunctions();
        \$form      = \$this->formModel->getRepository()->findOneById(\$event->getConfig()['form']);

        if (!\$form || !\$form->getId()) {
            return \$event->setResult(false);
        }

        \$field = \$this->formModel->findFormFieldByAlias(\$form, \$event->getConfig()['field']);

        \$filter = \$this->formFieldHelper->getFieldFilter(\$field->getType());
        \$value  = InputHelper::_(\$event->getConfig()['value'], \$filter);

        \$result = \$this->formSubmissionModel->getRepository()->compareValue(
            \$lead->getId(),
            \$form->getId(),
            \$form->getAlias(),
            \$event->getConfig()['field'],
            \$value,
            \$operators[\$event->getConfig()['operator']]['expr'],
            \$field ? \$field->getType() : null
        );

        \$event->setChannel('form', \$form->getId());

        return \$event->setResult(\$result);
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/FormBundle/EventListener/CampaignSubscriber.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/FormBundle/EventListener/CampaignSubscriber.php", "/var/www/html/mauticGIT-Test/app/bundles/FormBundle/EventListener/CampaignSubscriber.php");
    }
}
